package com.ruoyi.kaohe.mapper;

import java.util.List;
import com.ruoyi.kaohe.domain.KhEmployee;

/**
 * 职工信息Mapper接口
 * 
 * @author hs
 * @date 2025-06-17
 */
public interface KhEmployeeMapper 
{
    /**
     * 查询职工信息
     * 
     * @param id 职工信息主键
     * @return 职工信息
     */
    public KhEmployee selectKhEmployeeById(Long id);

    /**
     * 查询职工信息列表
     * 
     * @param khEmployee 职工信息
     * @return 职工信息集合
     */
    public List<KhEmployee> selectKhEmployeeList(KhEmployee khEmployee);

    /**
     * 新增职工信息
     * 
     * @param khEmployee 职工信息
     * @return 结果
     */
    public int insertKhEmployee(KhEmployee khEmployee);

    /**
     * 修改职工信息
     * 
     * @param khEmployee 职工信息
     * @return 结果
     */
    public int updateKhEmployee(KhEmployee khEmployee);

    /**
     * 删除职工信息
     * 
     * @param id 职工信息主键
     * @return 结果
     */
    public int deleteKhEmployeeById(Long id);

    /**
     * 批量删除职工信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKhEmployeeByIds(Long[] ids);
}
