package com.ruoyi.kaohe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.kaohe.domain.KhEmployee;
import com.ruoyi.kaohe.service.IKhEmployeeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 职工信息Controller
 * 
 * @author hs
 * @date 2025-06-17
 */
@RestController
@RequestMapping("/kaohe/employee")
public class KhEmployeeController extends BaseController
{
    @Autowired
    private IKhEmployeeService khEmployeeService;

    /**
     * 查询职工信息列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:employee:list')")
    @GetMapping("/list")
    public TableDataInfo list(KhEmployee khEmployee)
    {
        startPage();
        List<KhEmployee> list = khEmployeeService.selectKhEmployeeList(khEmployee);
        return getDataTable(list);
    }

    /**
     * 导出职工信息列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:employee:export')")
    @Log(title = "职工信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KhEmployee khEmployee)
    {
        List<KhEmployee> list = khEmployeeService.selectKhEmployeeList(khEmployee);
        ExcelUtil<KhEmployee> util = new ExcelUtil<KhEmployee>(KhEmployee.class);
        util.exportExcel(response, list, "职工信息数据");
    }

    /**
     * 获取职工信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:employee:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(khEmployeeService.selectKhEmployeeById(id));
    }

    /**
     * 新增职工信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:employee:add')")
    @Log(title = "职工信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KhEmployee khEmployee)
    {
        return toAjax(khEmployeeService.insertKhEmployee(khEmployee));
    }

    /**
     * 修改职工信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:employee:edit')")
    @Log(title = "职工信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KhEmployee khEmployee)
    {
        return toAjax(khEmployeeService.updateKhEmployee(khEmployee));
    }

    /**
     * 删除职工信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:employee:remove')")
    @Log(title = "职工信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(khEmployeeService.deleteKhEmployeeByIds(ids));
    }
}
